==> upload-api-client-internal-2.60.0.tgz: package/src/models/CopyFolderRequest.ts <==
/* istanbul ignore file */
/* tslint:disable */
/* eslint-disable */

import type { FolderPath } from "./FolderPath";
import type { IncludeFiles } from "./IncludeFiles";
import type { IncludeOverriddenStorage } from "./IncludeOverriddenStorage";
import type { IncludeVirtualFolders } from "./IncludeVirtualFolders";
import type { IterateFolderRecursively } from "./IterateFolderRecursively";
import type { TagCondition } from "./TagCondition";

/**
 * Request body for CopyFolder.
 *
 * You can use ListFolder to preview the operation: set `dryRun=true` with ```recursive```, ```includeFiles```, ```includeOverriddenStorage``` and ```includeVirtualFolders``` set to match the values you're using here. Leave all other flags unset.
 */
export type CopyFolderRequest = {
  /**
   * If specified, only files with tags that match this condition will be copied.
   */
  condition?: TagCondition;
  /**
   * If `true` then copies files.
   *
   * Default: true
   */
  copyFiles?: IncludeFiles;
  /**
   * If `true` then copies files from folders that have overridden storage settings, else skips them.
   *
   * If the current folder inherits its storage settings, then the current folder's files will be copied, assuming `copyFiles=true`.
   *
   * You can ignore this setting if your account does not use folders with overridden storage settings, such as custom AWS S3 buckets.
   *
   * Conditional: `copyVirtualFolders` and `copyOverriddenStorage` cannot both be `true`.
   *
   * Default: false
   */
  copyOverriddenStorage?: IncludeOverriddenStorage;
  /**
   * If `true` then copies virtual folder settings at the current path and below, else only files will be copied.
   *
   * Virtual folders are folders that have been created using the PutFolder operation.
   *
   * Conditional: `copyVirtualFolders` and `copyOverriddenStorage` cannot both be `true`.
   *
   * Default: true
   */
  copyVirtualFolders?: IncludeVirtualFolders;
  /**
   * Destination folder for the copy operation.
   *
   * The `source` folder will be copied to this location (rather than under it).
   */
  destination: FolderPath;
  /**
   * If `true` then copies files and virtual folders that are descendants of the `source` folder.
   *
   * If `false` then only copies files that are direct children of the `source` folder, and does not copy descendant virtual folders (children or otherwise).
   *
   * Default: true
   */
  recursive?: IterateFolderRecursively;
  /**
   * Source folder for the copy operation.
   */
  source: FolderPath;
};

==> upload-api-client-internal-2.64.0.tgz: package/src/models/CopyFolderRequest.ts <==
/* istanbul ignore file */
/* tslint:disable */
/* eslint-disable */

import type { FolderPath } from "./FolderPath";
import type { TagCondition } from "./TagCondition";

/**
 * Request body for CopyFolder.
 *
 * You can use ListFolder to preview the operation: set `dryRun=true` with ```recursive```, ```includeFiles```, ```includeOverriddenStorage``` and ```includeVirtualFolders``` set to match the values you're using here. Leave all other flags unset.
 */
export type CopyFolderRequest = {
  /**
   * If specified, only files with tags that match this condition will be copied.
   */
  condition?: TagCondition;
  /**
   * If `true` then copies files.
   *
   * Default: true
   */
  copyFiles?: boolean;
  /**
   * If `true` then copies files from folders that have overridden storage settings, else skips them.
   *
   * If the current folder inherits its storage settings, then the current folder's files will be copied, assuming `copyFiles=true`.
   *
   * You can ignore this setting if your account does not use folders with overridden storage settings, such as custom AWS S3 buckets.
   *
   * Conditional: `copyVirtualFolders` and `copyOverriddenStorage` cannot both be `true`.
   *
   * Default: false
   */
  copyOverriddenStorage?: boolean;
  /**
   * If `true` then copies virtual folder settings at the current path and below, else only files will be copied.
   *
   * Virtual folders are folders that have been created using the PutFolder operation.
   *
   * Conditional: `copyVirtualFolders` and `copyOverriddenStorage` cannot both be `true`.
   *
   * Default: true
   */
  copyVirtualFolders?: boolean;
  /**
   * Destination folder for the copy operation.
   *
   * The `source` folder will be copied to this location (rather than under it).
   */
  destination: FolderPath;
  /**
   * If `true` then copies files and virtual folders that are descendants of the `source` folder.
   *
   * If `false` then only copies files that are direct children of the `source` folder, and does not copy descendant virtual folders (children or otherwise).
   *
   * Default: true
   */
  recursive?: boolean;
  /**
   * Source folder for the copy operation.
   */
  source: FolderPath;
};
